@@ -1,13 +1,13 @@
 ci.c.ancova<-function(Psi=NULL, means=NULL, error.var.ancova=NULL, c.weights, n, x.bar, SSwithin.x, conf.level=.95, ...)
-{if (length(x.bar)!=length(c.weights) ) stop("The input 'x.bar' and 'c.weights' imply different numbers of groups")
+{if (length(x.bar)!=length(c.weights) ) stop("The input 'x.bar' and 'c.weights' imply different number of groups")
 
 if(is.null(Psi) & is.null(means) ) stop("Input either 'Psi' or 'means'")
-if(!is.null(Psi) & !is.null(means) ) stop("Do not input both 'Psi' and 'means'")
+if(!is.null(Psi) & !is.null(means) ) stop("Do not input both 'Psi' and 'means' at the same time")
 
 if(is.null(Psi)) Psi<- sum(means*c.weights)
 J<- length(c.weights)
 if(length(n)==1) n<-rep(n, J)
-if(length(n)>1 & length(n)!=length(c.weights)) stop("The input 'n' and 'c.weights' imply different numbers of groups ")
+if(length(n)>1 & length(n)!=length(c.weights)) stop("The input 'n' and 'c.weights' imply different number of groups ")
 ########################################################################
 f.x.numerater<- ( sum(c.weights*x.bar) )^2
 f.x.denominator<- SSwithin.x
